@@ -7,7 +7,7 @@ import json
 import logging
 import os
 from uuid import UUID
-from typing import Any, Dict, ForwardRef, Generic, List, Optional, Tuple, Type, TypeVar, Union, cast, get_args
+from typing import Any, Dict, ForwardRef, Generic, List, Optional, Set, Tuple, Type, TypeVar, Union, cast, get_args
 
 from vellum.client import Vellum as VellumClient
 from vellum.client.core.pydantic_utilities import UniversalBaseModel
@@ -15,6 +15,7 @@ from vellum.workflows import BaseWorkflow
 from vellum.workflows.constants import undefined
 from vellum.workflows.descriptors.base import BaseDescriptor
 from vellum.workflows.edges import Edge
+from vellum.workflows.edges.trigger_edge import TriggerEdge
 from vellum.workflows.events.workflow import NodeEventDisplayContext, WorkflowEventDisplayContext
 from vellum.workflows.inputs.base import BaseInputs
 from vellum.workflows.inputs.dataset_row import DatasetRow
@@ -27,6 +28,7 @@ from vellum.workflows.references import OutputReference, WorkflowInputReference
 from vellum.workflows.state.encoder import DefaultStateEncoder
 from vellum.workflows.triggers.integration import IntegrationTrigger
 from vellum.workflows.triggers.manual import ManualTrigger
+from vellum.workflows.triggers.schedule import ScheduleTrigger
 from vellum.workflows.types.core import Json, JsonArray, JsonObject
 from vellum.workflows.types.generics import WorkflowType
 from vellum.workflows.types.utils import get_original_base
@@ -141,7 +143,7 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
         for workflow_input_reference, workflow_input_display in self.display_context.workflow_input_displays.items():
             default = (
                 primitive_to_vellum_value(workflow_input_reference.instance)
-                if workflow_input_reference.instance
+                if workflow_input_reference.instance is not None and workflow_input_reference.instance is not undefined
                 else None
             )
 
@@ -161,7 +163,9 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
         state_variables: JsonArray = []
         for state_value_reference, state_value_display in self.display_context.state_value_displays.items():
             default = (
-                primitive_to_vellum_value(state_value_reference.instance) if state_value_reference.instance else None
+                primitive_to_vellum_value(state_value_reference.instance)
+                if state_value_reference.instance is not None and state_value_reference.instance is not undefined
+                else None
             )
 
             is_required = self._is_reference_required(state_value_reference)
@@ -181,20 +185,13 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
         edges: JsonArray = []
 
         # Get all trigger edges from the workflow's subgraphs to check if trigger exists
-        trigger_edges = []
+        trigger_edges: List[TriggerEdge] = []
         for subgraph in self._workflow.get_subgraphs():
             trigger_edges.extend(list(subgraph.trigger_edges))
 
         # Determine if we need an ENTRYPOINT node and what ID to use
-        # For ManualTrigger: create ENTRYPOINT node for backward compatibility
-        # For IntegrationTrigger only: no ENTRYPOINT node (use trigger ID directly in edges)
         manual_trigger_edges = [edge for edge in trigger_edges if issubclass(edge.trigger_class, ManualTrigger)]
-        integration_trigger_edges = [
-            edge for edge in trigger_edges if issubclass(edge.trigger_class, IntegrationTrigger)
-        ]
-
         has_manual_trigger = len(manual_trigger_edges) > 0
-        has_only_integration_trigger = len(integration_trigger_edges) > 0 and not has_manual_trigger
 
         entrypoint_node_id: Optional[UUID] = None
         entrypoint_node_source_handle_id: Optional[UUID] = None
@@ -218,8 +215,8 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
                 "base": None,
                 "definition": None,
             }
-        elif not trigger_edges:
-            # No trigger: use default ENTRYPOINT node (backward compatibility)
+        else:
+            # All other cases: use workflow_display ENTRYPOINT node
             entrypoint_node_id = self.display_context.workflow_display.entrypoint_node_id
             entrypoint_node_source_handle_id = self.display_context.workflow_display.entrypoint_node_source_handle_id
 
@@ -235,7 +232,7 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
                 "base": None,
                 "definition": None,
             }
-        # else: has_only_integration_trigger - no ENTRYPOINT node needed
+        # else: has_only_integration_trigger without explicit entrypoint - no ENTRYPOINT node needed
 
         # Add all the nodes in the workflows
         for node in self._workflow.get_all_nodes():
@@ -383,52 +380,75 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
             )
 
         # Add edges from trigger/entrypoint to first nodes
-        if has_only_integration_trigger:
-            # Use trigger ID directly as sourceNodeId (no ENTRYPOINT node)
-            trigger_class = integration_trigger_edges[0].trigger_class
+        nodes_with_trigger_edges: Set[Type[BaseNode]] = set()
+
+        for trigger_edge in trigger_edges:
+            target_node = trigger_edge.to_node
+            unadorned_target_node = get_unadorned_node(target_node)
+            nodes_with_trigger_edges.add(unadorned_target_node)
+
+            # Skip edges to invalid nodes
+            if self._is_node_invalid(unadorned_target_node):
+                continue
+
+            target_node_display = self.display_context.node_displays[unadorned_target_node]
+
+            # Get the entrypoint display for this target node (if it exists)
+            entrypoint_display = self.display_context.entrypoint_displays.get(target_node)
+            if entrypoint_display is None:
+                continue
+
+            trigger_class = trigger_edge.trigger_class
             trigger_id = trigger_class.__id__
-            trigger_source_handle_id = trigger_id  # Use trigger ID as handle ID
 
-            for target_node, entrypoint_display in self.display_context.entrypoint_displays.items():
-                unadorned_target_node = get_unadorned_node(target_node)
-                # Skip edges to invalid nodes
-                if self._is_node_invalid(unadorned_target_node):
-                    continue
+            # Determine source node ID and handle ID based on trigger type
+            if issubclass(trigger_class, ManualTrigger):
+                source_node_id = entrypoint_node_id
+                source_handle_id = entrypoint_node_source_handle_id
+            else:
+                source_node_id = trigger_id
+                source_handle_id = trigger_id
 
-                target_node_display = self.display_context.node_displays[unadorned_target_node]
-                trigger_edge_dict: Dict[str, Json] = {
-                    "id": str(entrypoint_display.edge_display.id),
-                    "source_node_id": str(trigger_id),
-                    "source_handle_id": str(trigger_source_handle_id),
-                    "target_node_id": str(target_node_display.node_id),
-                    "target_handle_id": str(target_node_display.get_trigger_id()),
-                    "type": "DEFAULT",
-                }
-                display_data = self._serialize_edge_display_data(entrypoint_display.edge_display)
-                if display_data is not None:
-                    trigger_edge_dict["display_data"] = display_data
-                edges.append(trigger_edge_dict)
-        elif entrypoint_node_id is not None:
-            # Traditional approach: edges from ENTRYPOINT node (backward compatibility)
-            for target_node, entrypoint_display in self.display_context.entrypoint_displays.items():
-                unadorned_target_node = get_unadorned_node(target_node)
-                # Skip edges to invalid nodes
-                if self._is_node_invalid(unadorned_target_node):
-                    continue
+            trigger_edge_dict: Dict[str, Json] = {
+                "id": str(entrypoint_display.edge_display.id),
+                "source_node_id": str(source_node_id),
+                "source_handle_id": str(source_handle_id),
+                "target_node_id": str(target_node_display.node_id),
+                "target_handle_id": str(target_node_display.get_trigger_id()),
+                "type": "DEFAULT",
+            }
+            display_data = self._serialize_edge_display_data(entrypoint_display.edge_display)
+            if display_data is not None:
+                trigger_edge_dict["display_data"] = display_data
+            edges.append(trigger_edge_dict)
 
-                target_node_display = self.display_context.node_displays[unadorned_target_node]
-                entrypoint_edge_dict: Dict[str, Json] = {
-                    "id": str(entrypoint_display.edge_display.id),
-                    "source_node_id": str(entrypoint_node_id),
-                    "source_handle_id": str(entrypoint_node_source_handle_id),
-                    "target_node_id": str(target_node_display.node_id),
-                    "target_handle_id": str(target_node_display.get_trigger_id()),
-                    "type": "DEFAULT",
-                }
-                display_data = self._serialize_edge_display_data(entrypoint_display.edge_display)
-                if display_data is not None:
-                    entrypoint_edge_dict["display_data"] = display_data
-                edges.append(entrypoint_edge_dict)
+        for target_node, entrypoint_display in self.display_context.entrypoint_displays.items():
+            unadorned_target_node = get_unadorned_node(target_node)
+
+            if unadorned_target_node in nodes_with_trigger_edges:
+                continue
+
+            # Skip edges to invalid nodes
+            if self._is_node_invalid(unadorned_target_node):
+                continue
+
+            if entrypoint_node_id is None:
+                continue
+
+            target_node_display = self.display_context.node_displays[unadorned_target_node]
+
+            entrypoint_edge_dict: Dict[str, Json] = {
+                "id": str(entrypoint_display.edge_display.id),
+                "source_node_id": str(entrypoint_node_id),
+                "source_handle_id": str(entrypoint_node_source_handle_id),
+                "target_node_id": str(target_node_display.node_id),
+                "target_handle_id": str(target_node_display.get_trigger_id()),
+                "type": "DEFAULT",
+            }
+            display_data = self._serialize_edge_display_data(entrypoint_display.edge_display)
+            if display_data is not None:
+                entrypoint_edge_dict["display_data"] = display_data
+            edges.append(entrypoint_edge_dict)
 
         for (source_node_port, target_node), edge_display in self.display_context.edge_displays.items():
             unadorned_source_node_port = get_unadorned_port(source_node_port)
@@ -524,66 +544,64 @@ class BaseWorkflowDisplay(Generic[WorkflowType]):
             # No workflow-level trigger defined
             return None
 
-        # Get the trigger class from the first edge
-        trigger_class = trigger_edges[0].trigger_class
+        unique_trigger_classes = list(dict.fromkeys(edge.trigger_class for edge in trigger_edges))
 
-        # Validate that all trigger edges use the same trigger type
         trigger_type_mapping = get_trigger_type_mapping()
-        for edge in trigger_edges:
-            if edge.trigger_class != trigger_class:
-                raise ValueError(
-                    f"Mixed trigger types not supported. Found {trigger_class.__name__} and "
-                    f"{edge.trigger_class.__name__} in the same workflow."
-                )
+        serialized_triggers: List[JsonObject] = []
 
-        # Get the trigger type from the mapping, or check if it's an IntegrationTrigger subclass
-        trigger_type = trigger_type_mapping.get(trigger_class)
-        if trigger_type is None:
-            # Check if it's an IntegrationTrigger subclass
+        for trigger_class in unique_trigger_classes:
+            # Get the trigger type from the mapping, or check if it's a subclass
+            trigger_type = trigger_type_mapping.get(trigger_class)
+            if trigger_type is None:
+                # Check if it's a subclass of a known trigger type
+                if issubclass(trigger_class, ManualTrigger):
+                    trigger_type = WorkflowTriggerType.MANUAL
+                elif issubclass(trigger_class, IntegrationTrigger):
+                    trigger_type = WorkflowTriggerType.INTEGRATION
+                elif issubclass(trigger_class, ScheduleTrigger):
+                    trigger_type = WorkflowTriggerType.SCHEDULED
+                else:
+                    raise ValueError(
+                        f"Unknown trigger type: {trigger_class.__name__}. "
+                        f"Please add it to the trigger type mapping in get_trigger_type_mapping()."
+                    )
 
-            if issubclass(trigger_class, IntegrationTrigger):
-                trigger_type = WorkflowTriggerType.INTEGRATION
-            else:
-                raise ValueError(
-                    f"Unknown trigger type: {trigger_class.__name__}. "
-                    f"Please add it to the trigger type mapping in get_trigger_type_mapping()."
-                )
+            trigger_id = trigger_class.__id__
 
-        # Return as a list with a single trigger object matching Django schema
-        trigger_id = trigger_class.__id__
+            # Serialize trigger attributes like node outputs
+            attribute_references = trigger_class.attribute_references().values()
+            trigger_attributes: JsonArray = cast(
+                JsonArray,
+                [
+                    cast(
+                        JsonObject,
+                        {
+                            "id": str(reference.id),
+                            "name": reference.name,
+                            "type": primitive_type_to_vellum_variable_type(reference),
+                            "value": None,
+                        },
+                    )
+                    for reference in sorted(attribute_references, key=lambda ref: ref.name)
+                ],
+            )
 
-        # Serialize trigger attributes like node outputs
-        attribute_references = trigger_class.attribute_references().values()
-        trigger_attributes: JsonArray = cast(
-            JsonArray,
-            [
-                cast(
-                    JsonObject,
-                    {
-                        "id": str(reference.id),
-                        "name": reference.name,
-                        "type": primitive_type_to_vellum_variable_type(reference),
-                        "value": None,
-                    },
-                )
-                for reference in sorted(attribute_references, key=lambda ref: ref.name)
-            ],
-        )
+            trigger_data: JsonObject = {
+                "id": str(trigger_id),
+                "type": trigger_type.value,
+                "attributes": trigger_attributes,
+            }
 
-        trigger_data: JsonObject = {
-            "id": str(trigger_id),
-            "type": trigger_type.value,
-            "attributes": trigger_attributes,
-        }
+            # For INTEGRATION and SCHEDULED triggers, include class name, module path, and source_handle_id
+            # ManualTrigger doesn't need source_handle_id because edges come from ENTRYPOINT node
+            if trigger_type in (WorkflowTriggerType.INTEGRATION, WorkflowTriggerType.SCHEDULED):
+                trigger_data["class_name"] = trigger_class.__name__
+                trigger_data["module_path"] = cast(Json, trigger_class.__module__.split("."))
+                trigger_data["source_handle_id"] = str(trigger_id)  # Trigger acts as edge source
 
-        # For INTEGRATION triggers, include class name, module path, and source_handle_id
-        # ManualTrigger doesn't need source_handle_id because edges come from ENTRYPOINT node
-        if trigger_type == WorkflowTriggerType.INTEGRATION:
-            trigger_data["class_name"] = trigger_class.__name__
-            trigger_data["module_path"] = cast(Json, trigger_class.__module__.split("."))
-            trigger_data["source_handle_id"] = str(trigger_id)  # IntegrationTrigger acts as edge source
+            serialized_triggers.append(trigger_data)
 
-        return cast(JsonArray, [trigger_data])
+        return cast(JsonArray, serialized_triggers)
 
     def _serialize_edge_display_data(self, edge_display: EdgeDisplay) -> Optional[JsonObject]:
         """Serialize edge display data, returning None if no display data is present."""
