@@ -114,6 +114,16 @@ class BaseNodeMeta(ABCMeta):
                     dct["Ports"] = type(f"{name}.Ports", (base.Ports,), ports_dct)
                     break
 
+        if "Display" not in dct:
+            for base in reversed(bases):
+                if issubclass(base, BaseNode):
+                    dct["Display"] = type(
+                        f"{name}.Display",
+                        (base.Display,),
+                        {"__module__": dct["__module__"]},
+                    )
+                    break
+
         if "Execution" not in dct:
             for base in reversed(bases):
                 if issubclass(base, BaseNode):
@@ -304,6 +314,12 @@ class BaseNode(Generic[StateType], ABC, BaseExecutable, metaclass=BaseNodeMeta):
     class Ports(NodePorts):
         default = Port(default=True)
 
+    class Display:
+        """Optional display metadata for visual representation."""
+
+        icon: Optional[str] = None
+        color: Optional[str] = None
+
     class Trigger(metaclass=_BaseNodeTriggerMeta):
         node_class: Type["BaseNode"]
         merge_behavior = MergeBehavior.AWAIT_ATTRIBUTES
